Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1354)

Unified Diff: chrome/browser/autocomplete/zero_suggest_provider.h

Issue 671593002: Do not delay most visited results. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Addressed comments Created 6 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/autocomplete/zero_suggest_provider.h
diff --git a/chrome/browser/autocomplete/zero_suggest_provider.h b/chrome/browser/autocomplete/zero_suggest_provider.h
index c10a622cbf2a101afbfd7152d4edfdb55307baa7..8c1fccabbf6c6dbc977362710c9a5f28633a750e 100644
--- a/chrome/browser/autocomplete/zero_suggest_provider.h
+++ b/chrome/browser/autocomplete/zero_suggest_provider.h
@@ -120,10 +120,11 @@ class ZeroSuggestProvider : public BaseSearchProvider,
// Returns the relevance score for the verbatim result.
int GetVerbatimRelevance() const;
- // Whether we can show zero suggest on |current_page_url| without
- // sending |current_page_url| as a parameter to the server at |suggest_url|.
- bool CanShowZeroSuggestWithoutSendingURL(const GURL& suggest_url,
- const GURL& current_page_url) const;
+ // Whether we can show zero suggest without sending |current_page_url| to
+ // |suggest_url| search provider. Also checks that other conditions for
+ // non-contextual zero suggest are satisfied.
+ bool ShouldShowNonContextualZeroSuggest(const GURL& suggest_url,
+ const GURL& current_page_url) const;
// Checks whether we have a set of zero suggest results cached, and if so
// populates |matches_| with cached results.

Powered by Google App Engine
This is Rietveld 408576698